@@ -17,9 +17,11 @@
 #include <cassert>
 #include <limits>
 
+#include "test_macros.h"
+
 int new_handler_called = 0;
 
-void new_handler()
+void my_new_handler()
 {
     ++new_handler_called;
     std::set_new_handler(0);
@@ -35,10 +37,12 @@ struct A
 
 int main()
 {
-    std::set_new_handler(new_handler);
+#ifndef TEST_HAS_NO_EXCEPTIONS
+    std::set_new_handler(my_new_handler);
     try
     {
-        void*volatile vp = operator new[] (std::numeric_limits<std::size_t>::max());
+        void* volatile vp = operator new[] (std::numeric_limits<std::size_t>::max());
+        ((void)vp);
         assert(false);
     }
     catch (std::bad_alloc&)
@@ -49,6 +53,7 @@ int main()
     {
         assert(false);
     }
+#endif
     A* ap = new A[3];
     assert(ap);
     assert(A_constructed == 3);
