@@ -7,10 +7,17 @@
 //
 //===----------------------------------------------------------------------===//
 
+// UNSUPPORTED: libcxxabi-no-exceptions
+// REQUIRES: c++98 || c++03 || c++11 || c++14
+
 #include <exception>
 #include <stdlib.h>
 #include <assert.h>
 
+#if defined(__GNUC__)
+#pragma GCC diagnostic ignored "-Wunreachable-code"
+#endif
+
 struct A
 {
     static int count;
